@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "sparkweather" "0.1.2"
+(define-package "sparkweather" "20260112.1420"
   "Weather forecasts with sparklines."
   '((emacs "29.1"))
   :url "https://github.com/aglet/sparkweather"
-  :commit "99b096e4c4c4181d45d8fb77faf8698249287ac8"
-  :revdesc "99b096e4c4c4"
+  :commit "967fbddc81ab04ff11baba9bd6739d74f5bc593a"
+  :revdesc "967fbddc81ab"
   :keywords '("convenience" "weather")
   :authors '(("Robin Stephenson" . "robin@aglet.net"))
   :maintainers '(("Robin Stephenson" . "robin@aglet.net")))
